@@ -21,7 +21,6 @@
   limitations under the License.
  */
 
-
 /****************************************************************************
 
   I_HostDB.h
@@ -29,8 +28,7 @@
 
  ****************************************************************************/
 
-#ifndef _I_HostDB_h_
-#define _I_HostDB_h_
+#pragma once
 
 #include "I_EventSystem.h"
 #include "I_Net.h"
@@ -39,10 +37,6 @@
 #include "I_HostDBProcessor.h"
 
 // TS-1925: switch from MMH to MD5 hash; bumped to version 2
+// switch from MD5 to SHA256 hash; bumped to version 3
 // 2.1: Switched to mark RR elements.
-#define HOSTDB_MODULE_MAJOR_VERSION 2
-#define HOSTDB_MODULE_MINOR_VERSION 1
-
-#define HOSTDB_MODULE_VERSION makeModuleVersion(HOSTDB_MODULE_MAJOR_VERSION, HOSTDB_MODULE_MINOR_VERSION, PUBLIC_MODULE_HEADER)
-
-#endif /* _I_HostDB_h_ */
+static constexpr ts::ModuleVersion HOSTDB_MODULE_PUBLIC_VERSION(3, 1);
