@@ -21,16 +21,15 @@
   limitations under the License.
  */
 
-#ifndef _UDP_IO_EVENT_H_
-#define _UDP_IO_EVENT_H_
+#pragma once
 // ugly -- just encapsulate the I/O result so that it can be passed
 // back to the caller via continuation handler.
 
 class UDPIOEvent : public Event
 {
 public:
-  UDPIOEvent() : fd(-1), err(0), m(0), handle(0), b(0), bytesTransferred(0){};
-  ~UDPIOEvent(){};
+  UDPIOEvent() : b(nullptr){};
+  ~UDPIOEvent() override{};
 
   void
   setInfo(int fd_, const Ptr<IOBufferBlock> &b_, int bytesTransferred_, int errno_)
@@ -91,20 +90,19 @@ public:
 
 private:
   void *operator new(size_t size); // undefined
-  int fd;
-  int err; // error code
-  struct msghdr *m;
-  void *handle;         // some extra data for the client handler
-  Ptr<IOBufferBlock> b; // holds buffer that I/O will go to
-  int bytesTransferred; // actual bytes transferred
+  int fd           = -1;
+  int err          = 0; // error code
+  struct msghdr *m = nullptr;
+  void *handle     = nullptr; // some extra data for the client handler
+  Ptr<IOBufferBlock> b;       // holds buffer that I/O will go to
+  int bytesTransferred = 0;   // actual bytes transferred
 };
 
 extern ClassAllocator<UDPIOEvent> UDPIOEventAllocator;
 TS_INLINE void
 UDPIOEvent::free(UDPIOEvent *e)
 {
-  e->b     = NULL;
-  e->mutex = NULL;
+  e->b     = nullptr;
+  e->mutex = nullptr;
   UDPIOEventAllocator.free(e);
 }
-#endif
