@@ -22,6 +22,9 @@
  */
 
 #include "P_Net.h"
+
+#include "tscore/ink_hw.h"
+
 #include <netdb.h>
 
 #include "diags.i"
@@ -29,22 +32,21 @@
 /*
  * Choose a net test application
  */
-//#include "NetTest-http-server.c"
 #include "NetTest-simple-proxy.c"
 
 int
 main()
 {
   // do not buffer stdout
-  setbuf(stdout, NULL);
+  setbuf(stdout, nullptr);
   int nproc = ink_number_of_processors();
 
   RecModeT mode_type = RECM_STAND_ALONE;
 
-  init_diags("net_test", NULL);
+  init_diags("net_test", nullptr);
   RecProcessInit(mode_type);
-  ink_event_system_init(EVENT_SYSTEM_MODULE_VERSION);
-  ink_net_init(NET_SYSTEM_MODULE_VERSION);
+  ink_event_system_init(EVENT_SYSTEM_MODULE_PUBLIC_VERSION);
+  ink_net_init(NET_SYSTEM_MODULE_PUBLIC_VERSION);
 
   /*
    * ignore broken pipe
@@ -58,9 +60,9 @@ main()
   eventProcessor.start(nproc);
   RecProcessStart();
 
-/*
- *  Reset necessary config variables
- */
+  /*
+   *  Reset necessary config variables
+   */
 
 #ifdef USE_SOCKS
   net_config_socks_server_host = "209.131.52.54";
