@@ -58,6 +58,7 @@ struct AuthOptions {
   int hostport                   = -1;
   AuthRequestTransform transform = nullptr;
   bool force                     = false;
+  bool cache_internal_requests   = false;
 
   AuthOptions()  = default;
   ~AuthOptions() = default;
@@ -633,6 +634,14 @@ AuthRequestIsTagged(TSHttpTxn txn)
   return AuthTaggedRequestArg != -1 && TSUserArgGet(txn, AuthTaggedRequestArg) != nullptr;
 }
 
+// Return true if the internal requests can be cached.
+static bool
+CacheInternalRequests(TSHttpTxn txn)
+{
+  AuthOptions *opt = static_cast<AuthOptions *>(TSUserArgGet(txn, AuthTaggedRequestArg));
+  return opt ? opt->cache_internal_requests : false;
+}
+
 static int
 AuthProxyGlobalHook(TSCont /* cont ATS_UNUSED */, TSEvent event, void *edata)
 {
@@ -651,8 +660,8 @@ AuthProxyGlobalHook(TSCont /* cont ATS_UNUSED */, TSEvent event, void *edata)
       // it as a global plugin (not highly recommended). Also remember that
       // the HEAD auth request might trip a different remap rule, particularly
       // if you do not have pristine host-headers enabled.
-      TSHttpTxnConfigIntSet(txn, TS_CONFIG_HTTP_CACHE_HTTP, 0);
-
+      if (!CacheInternalRequests(txn))
+        TSHttpTxnConfigIntSet(txn, TS_CONFIG_HTTP_CACHE_HTTP, 0);
       AuthLogDebug("re-enabling internal transaction");
       TSHttpTxnReenable(txn, TS_EVENT_HTTP_CONTINUE);
       return TS_EVENT_NONE;
@@ -683,6 +692,7 @@ AuthParseOptions(int argc, const char **argv)
     {const_cast<char *>("auth-port"), required_argument, nullptr, 'p'},
     {const_cast<char *>("auth-transform"), required_argument, nullptr, 't'},
     {const_cast<char *>("force-cacheability"), no_argument, nullptr, 'c'},
+    {const_cast<char *>("cache-internal"), no_argument, nullptr, 'i'},
     {nullptr, 0, nullptr, 0},
   };
 
@@ -704,6 +714,9 @@ AuthParseOptions(int argc, const char **argv)
     case 'c':
       options->force = true;
       break;
+    case 'i':
+      options->cache_internal_requests = true;
+      break;
     case 't':
       if (strcasecmp(optarg, "redirect") == 0) {
         options->transform = AuthWriteRedirectedRequest;
