@@ -42,7 +42,7 @@ using namespace std;
 using namespace Gzip;
 
 // FIXME: custom dictionaries would be nice. configurable/content-type?
-// a GPRS device might benefit from a higher compression ratio, whereas a desktop w. high bandwith
+// a GPRS device might benefit from a higher compression ratio, whereas a desktop w. high bandwidth
 // might be served better with little or no compression at all
 // FIXME: look into compressing from the task thread pool
 // FIXME: make normalizing accept encoding configurable
@@ -55,8 +55,6 @@ using namespace Gzip;
 
 const int ZLIB_COMPRESSION_LEVEL = 6;
 const char *dictionary           = nullptr;
-const char *TS_HTTP_VALUE_BROTLI = "br";
-const int TS_HTTP_LEN_BROTLI     = 2;
 
 // brotli compression quality 1-11. Testing proved level '6'
 #if HAVE_BROTLI_ENCODE_H
@@ -761,7 +759,7 @@ transformable(TSHttpTxn txnp, bool server, HostConfiguration *host_configuration
     }
 
     if (hdr_value < host_configuration->minimum_content_length()) {
-      info("response is is smaller than minimum content length, not compressing");
+      info("response is smaller than minimum content length, not compressing");
       return 0;
     }
   }
