@@ -29,7 +29,7 @@ constexpr char const PLUGIN_NAME[] = "TLS Bridge";
 constexpr char const PLUGIN_TAG[]  = "tls_bridge";
 
 // Base format string for making the internal CONNECT.
-char const CONNECT_FORMAT[] = "CONNECT https:%.*s HTTP/1.1\r\n\r\n";
+char const CONNECT_FORMAT[] = "CONNECT https://%.*s HTTP/1.1\r\n\r\n";
 
 // TextView of the 'CONNECT' method string.
 const TextView METHOD_CONNECT{TS_HTTP_METHOD_CONNECT, TS_HTTP_LEN_CONNECT};
@@ -673,7 +673,7 @@ CB_Read_Request_Hdr(TSCont contp, TSEvent ev_idx, void *data)
           // Arrange for cleanup.
           TSHttpTxnHookAdd(txn, TS_HTTP_TXN_CLOSE_HOOK, actor);
           // Skip remap and remap rule requirement - authorized by TLS bridge config.
-          TSSkipRemappingSet(txn, 1);
+          TSHttpTxnCntlSet(txn, TS_HTTP_CNTL_SKIP_REMAPPING, true);
           // Grab the transaction
           TSHttpTxnIntercept(actor, txn);
         }
