@@ -29,22 +29,22 @@ ts = Test.MakeATSProcess("ts1", select_ports=True, enable_tls=False)
 server = Test.MakeOriginServer("server")
 
 testName = ""
-request_header = {"headers": "POST /case1 HTTP/1.1\r\nHost: www.example.com\r\nuuid:1\r\n\r\n",
-                  "timestamp": "1469733493.993",
-                  "body": "stuff"
-                  }
-response_header = {"headers": "HTTP/1.1 200 OK\r\nServer: uServer\r\nConnection: close\r\nTransfer-Encoding: chunked\r\n\r\n",
-                   "timestamp": "1469733493.993",
-                   "body": "more stuff"}
+request_header = {
+    "headers": "POST /case1 HTTP/1.1\r\nHost: www.example.com\r\nuuid:1\r\n\r\n",
+    "timestamp": "1469733493.993",
+    "body": "stuff"
+}
+response_header = {
+    "headers": "HTTP/1.1 200 OK\r\nServer: uServer\r\nConnection: close\r\nTransfer-Encoding: chunked\r\n\r\n",
+    "timestamp": "1469733493.993",
+    "body": "more stuff"
+}
 
 server.addResponse("sessionlog.json", request_header, response_header)
 
-ts.Disk.records_config.update({'proxy.config.diags.debug.enabled': 0,
-                               'proxy.config.diags.debug.tags': 'http'})
+ts.Disk.records_config.update({'proxy.config.diags.debug.enabled': 0, 'proxy.config.diags.debug.tags': 'http'})
 
-ts.Disk.remap_config.AddLine(
-    'map / http://127.0.0.1:{0}'.format(server.Variables.Port)
-)
+ts.Disk.remap_config.AddLine('map / http://127.0.0.1:{0}'.format(server.Variables.Port))
 
 # HTTP1.1 POST: www.example.com/case1 with gzip transfer-encoding
 tr = Test.AddTestRun()
@@ -84,19 +84,16 @@ class HTTP10Test:
     def setupTS(self):
         self.ts = Test.MakeATSProcess("ts2", enable_tls=True, enable_cache=False)
         self.ts.addDefaultSSLFiles()
-        self.ts.Disk.records_config.update({
-            "proxy.config.diags.debug.enabled": 1,
-            "proxy.config.diags.debug.tags": "http",
-            "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
-        })
-        self.ts.Disk.ssl_multicert_config.AddLine(
-            'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-        )
-        self.ts.Disk.remap_config.AddLine(
-            f"map / http://127.0.0.1:{self.server.Variables.http_port}/",
-        )
+        self.ts.Disk.records_config.update(
+            {
+                "proxy.config.diags.debug.enabled": 1,
+                "proxy.config.diags.debug.tags": "http",
+                "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
+            })
+        self.ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
+        self.ts.Disk.remap_config.AddLine(f"map / http://127.0.0.1:{self.server.Variables.http_port}/",)
 
     def runChunkedTraffic(self):
         tr = Test.AddTestRun()
@@ -128,41 +125,35 @@ class MalformedChunkHeaderTest:
     def setupOriginServer(self):
         self.server = Test.MakeVerifierServerProcess("verifier-server2", self.chunkedReplayFile)
 
-        # The server's responses will fail the first two transactions
+        # The server's responses will fail the first three transactions
         # because ATS will close the connection due to the malformed
         # chunk headers.
         self.server.Streams.stdout += Testers.ContainsExpression(
-            "Unexpected chunked content for key 1: too small",
-            "Verify that writing the first response failed.")
-        self.server.Streams.stdout += Testers.ContainsExpression(
-            "Unexpected chunked content for key 2: too small",
-            "Verify that writing the second response failed.")
-
-        # ATS should close the connection before any body gets through. "abc"
-        # is the body sent by the client for each of these chunked cases.
+            "Unexpected chunked content for key 1: too small", "Verify that writing the first response failed.")
         self.server.Streams.stdout += Testers.ExcludesExpression(
-            "abc",
-            "Verify that the body never got through.")
+            "chunked body of 3 bytes for key 2 with chunk stream", "Verify that writing the second response failed.")
+        self.server.Streams.stdout += Testers.ContainsExpression(
+            "Unexpected chunked content for key 3: too small", "Verify that writing the third response failed.")
+
+        # ATS should close the connection before any body gets through. "abcwxyz"
+        # is the body sent by the client for each of these chunked cases.
+        self.server.Streams.stdout += Testers.ExcludesExpression("abcwxyz", "Verify that the body never got through.")
 
     def setupTS(self):
         self.ts = Test.MakeATSProcess("ts3", enable_tls=True, enable_cache=False)
         self.ts.addDefaultSSLFiles()
-        self.ts.Disk.records_config.update({
-            "proxy.config.diags.debug.enabled": 1,
-            "proxy.config.diags.debug.tags": "http",
-            "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
-            "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
-        })
-        self.ts.Disk.ssl_multicert_config.AddLine(
-            'dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key'
-        )
-        self.ts.Disk.remap_config.AddLine(
-            f"map / http://127.0.0.1:{self.server.Variables.http_port}/",
-        )
-        self.ts.Streams.stderr += Testers.ContainsExpression(
-            "user agent post chunk decoding error",
-            "Verify that ATS detected a problem parsing a chunk.")
+        self.ts.Disk.records_config.update(
+            {
+                "proxy.config.diags.debug.enabled": 1,
+                "proxy.config.diags.debug.tags": "http",
+                "proxy.config.ssl.server.cert.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.server.private_key.path": f'{self.ts.Variables.SSLDir}',
+                "proxy.config.ssl.client.verify.server.policy": 'PERMISSIVE',
+            })
+        self.ts.Disk.ssl_multicert_config.AddLine('dest_ip=* ssl_cert_name=server.pem ssl_key_name=server.key')
+        self.ts.Disk.remap_config.AddLine(f"map / http://127.0.0.1:{self.server.Variables.http_port}/",)
+        self.ts.Disk.traffic_out.Content += Testers.ContainsExpression(
+            "user agent post chunk decoding error", "Verify that ATS detected a problem parsing a chunk.")
 
     def runChunkedTraffic(self):
         tr = Test.AddTestRun()
@@ -181,17 +172,18 @@ class MalformedChunkHeaderTest:
         # code from the verifier client.
         tr.Processes.Default.ReturnCode = 1
         tr.Processes.Default.Streams.stdout += Testers.ContainsExpression(
-            r"(Unexpected chunked content for key 3: too small|Failed HTTP/1 transaction with key: 3)",
-            "Verify that ATS closed the third transaction.")
+            r"(Unexpected chunked content for key 101: too small|Failed HTTP/1 transaction with key: 101)",
+            "Verify that ATS closed the forth transaction.")
         tr.Processes.Default.Streams.stdout += Testers.ContainsExpression(
-            r"(Unexpected chunked content for key 4: too small|Failed HTTP/1 transaction with key: 4)",
-            "Verify that ATS closed the fourth transaction.")
+            r"(Unexpected chunked content for key 102: too small|Failed HTTP/1 transaction with key: 102)",
+            "Verify that ATS closed the fifth transaction.")
+        tr.Processes.Default.Streams.stdout += Testers.ContainsExpression(
+            r"(Unexpected chunked content for key 103: too small|Failed HTTP/1 transaction with key: 103)",
+            "Verify that ATS closed the sixth transaction.")
 
         # ATS should close the connection before any body gets through. "def"
         # is the body sent by the server for each of these chunked cases.
-        tr.Processes.Default.Streams.stdout += Testers.ExcludesExpression(
-            "def",
-            "Verify that the body never got through.")
+        tr.Processes.Default.Streams.stdout += Testers.ExcludesExpression("def", "Verify that the body never got through.")
 
     def run(self):
         self.runChunkedTraffic()
